/**
 * Vanilla JS Match Height
 *
 * v1.0.6
 *
 * Josh Donnell
 *
 * @class
 */
import { OptionsDefault, Options, IMatchHeight, MatchHeightItem } from './types';
declare class MatchHeight implements IMatchHeight {
    element: string;
    elements: MatchHeightItem[];
    options: Options;
    constructor(element: string, options?: OptionsDefault);
    /**
     * Simple function to run on inital load
     * after the dom is registered
     */
    init(): void;
    /**
     * Find all elements from parent
     * or from gloal document and
     * cache for updates.
     */
    findElements(): void;
    /**
     * Groups rows by offset if set
     * when registering match height
     */
    findRows(): void;
    /**
     * Create group from elements and a parent
     * also set the data back to the elements array
     *
     * @param {Array} elements
     * @param {Element} parent
     */
    createGroup(elements: NodeListOf<HTMLElement>, parent?: HTMLElement): void;
    /**
     * Set the largest heights in our
     * groups of elements.
     *
     */
    setHeights(): void;
    /**
     * Function used to trigger updades,
     * these can be triggered manually or
     *  are already set to run on resize
     */
    update(): void;
    /**
     * Reset all heights and refind groups and rows
     * for all the elements in the group.
     * This is best to be used when updating the
     * content of a page as the prevoius values
     * will be cached in out elements object.
     */
    reset(): void;
    /**
     * Basic function to log the current cache
     * for the class. Can be useful if you are facing an issue.
     */
    debug(): void;
    /**
     * Basic function to log the current cache
     * for the class. Can be useful if you are facing an issue.
     *
     * @param {string} type
     */
    error(type?: string): void;
}
export default MatchHeight;
